@@ -1,4 +1,3 @@
-/* $Xorg: OpenDis.c,v 1.4 2001/02/09 02:03:34 xorgcvs Exp $ */
 /*
 
 Copyright 1985, 1986, 1998  The Open Group
@@ -24,20 +23,12 @@ used in advertising or otherwise to promote the sale, use or other dealings
 in this Software without prior written authorization from The Open Group.
 
 */
-/* $XFree86: xc/lib/X11/OpenDis.c,v 3.16 2003/07/04 16:24:23 eich Exp $ */
 
-#define NEED_REPLIES
-#define NEED_EVENTS
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 #include "Xlibint.h"
-#if USE_XCB
 #include "Xxcbint.h"
-#else /* !USE_XCB */
-#include <X11/Xtrans/Xtrans.h>
-#include <X11/extensions/bigreqstr.h>
-#endif /* USE_XCB */
 #include <X11/Xatom.h>
 #include <X11/Xresource.h>
 #include <stdio.h>
@@ -47,21 +38,6 @@ in this Software without prior written authorization from The Open Group.
 #include "XKBlib.h"
 #endif /* XKB */
 
-#if !USE_XCB
-#ifdef X_NOT_POSIX
-#define Size_t unsigned int
-#else
-#define Size_t size_t
-#endif
-
-#define bignamelen (sizeof(XBigReqExtensionName) - 1)
-
-typedef struct {
-    unsigned long seq;
-    int opcode;
-} _XBigReqState;
-#endif /* !USE_XCB */
-
 #ifdef XTHREADS
 #include "locking.h"
 int  (*_XInitDisplayLock_fn)(Display *dpy) = NULL;
@@ -78,11 +54,7 @@ static xReq _dummy_request = {
 	0, 0, 0
 };
 
-static void OutOfMemory(Display *dpy, char *setup);
-#if !USE_XCB
-static Bool _XBigReqHandler(Display *dpy, xReply *rep, char *buf, int len,
-				XPointer data);
-#endif /* !USE_XCB */
+static void OutOfMemory(Display *dpy);
 
 /*
  * Connects to a server, creates a Display object and returns a pointer to
@@ -95,17 +67,8 @@ XOpenDisplay (
 	register Display *dpy;		/* New Display object being created. */
 	register int i;
 	int j, k;			/* random iterator indexes */
-#if !USE_XCB
 	char *display_name;		/* pointer to display name */
-	int endian;			/* to determine which endian. */
-	xConnClientPrefix client;	/* client information */
-	int idisplay;			/* display number */
-	int prefixread = 0;             /* setup prefix already read? */
-	char *conn_auth_name, *conn_auth_data;
-	int conn_auth_namelen, conn_auth_datalen;
-#endif /* !USE_XCB */
 	char *setup = NULL;		/* memory allocated at startup */
-	char *fullname = NULL;		/* expanded name of display */
 	int iscreen;			/* screen number */
 	xConnSetupPrefix prefix;	/* prefix information */
 	int vendorlen;			/* length of vendor string */
@@ -121,12 +84,8 @@ XOpenDisplay (
 	long setuplength;	/* number of bytes in setup message */
 	long usedbytes = 0;     /* number of bytes we have processed */
 	unsigned long mask;
-       long int conn_buf_size;
-       char *xlib_buffer_size;
-
-#if !USE_XCB
-	bzero((char *) &client, sizeof(client));
-	bzero((char *) &prefix, sizeof(prefix));
+	long int conn_buf_size;
+	char *xlib_buffer_size;
 
 	/*
 	 * If the display specifier string supplied as an argument to this
@@ -142,7 +101,6 @@ XOpenDisplay (
 		/* Display is non-NULL, copy the pointer */
 		display_name = (char *)display;
 	}
-#endif /* !USE_XCB */
 
 /*
  * Set the default error handlers.  This allows the global variables to
@@ -158,36 +116,25 @@ XOpenDisplay (
 		return(NULL);
 	}
 
-/*
- * Call the Connect routine to get the transport connection object.
- * If NULL is returned, the connection failed. The connect routine
- * will set fullname to point to the expanded name.
- */
-
-#if USE_XCB
-	if(!_XConnectXCB(dpy, display, &fullname, &iscreen)) {
-		dpy->display_name = fullname;
-		OutOfMemory(dpy, 0);
-		return 0;
-	}
-#else /* !USE_XCB */
-	if ((dpy->trans_conn = _X11TransConnectDisplay (
-					 display_name, &fullname, &idisplay,
-					 &iscreen, &conn_auth_name,
-					 &conn_auth_namelen, &conn_auth_data,
-					 &conn_auth_datalen)) == NULL) {
-		Xfree ((char *) dpy);
+	if ((dpy->display_name = strdup(display_name)) == NULL) {
+		OutOfMemory(dpy);
 		return(NULL);
 	}
 
-	dpy->fd = _X11TransGetConnectionNumber (dpy->trans_conn);
-#endif /* USE_XCB */
+/*
+ * Call the Connect routine to get the transport connection object.
+ * If NULL is returned, the connection failed.
+ */
+
+	if(!_XConnectXCB(dpy, display, &iscreen)) {
+		OutOfMemory(dpy);
+		return NULL;
+	}
 
 	/* Initialize as much of the display structure as we can.
 	 * Initialize pointers to NULL so that XFreeDisplayStructure will
 	 * work if we run out of memory before we finish initializing.
 	 */
-	dpy->display_name	= fullname;
 	dpy->keysyms		= (KeySym *) NULL;
 	dpy->modifiermap	= NULL;
 	dpy->lock_meaning	= NoSymbol;
@@ -257,12 +204,12 @@ XOpenDisplay (
 
 	/* Initialize the display lock */
 	if (InitDisplayLock(dpy) != 0) {
-	        OutOfMemory (dpy, setup);
+	        OutOfMemory (dpy);
 		return(NULL);
 	}
 
 	if (!_XPollfdCacheInit(dpy)) {
-	        OutOfMemory (dpy, setup);
+	        OutOfMemory (dpy);
 		return(NULL);
 	}
 
@@ -273,23 +220,27 @@ XOpenDisplay (
 #ifndef XLIBMINBUFSIZE
 #define XLIBMINBUFSIZE BUFSIZE /* old default buffer size */
 #endif
-    if ((xlib_buffer_size = getenv("XLIBBUFFERSIZE")) == NULL)
-        conn_buf_size = XLIBDEFAULTBUFSIZE;
-    else
-        conn_buf_size = 1024 * strtol(xlib_buffer_size, NULL, 10);
-    if (conn_buf_size < XLIBMINBUFSIZE)
-        conn_buf_size = XLIBMINBUFSIZE;
+	xlib_buffer_size = getenv("XLIBBUFFERSIZE");
 
-    if ((dpy->bufptr = dpy->buffer = Xcalloc(1, conn_buf_size)) == NULL) {
-         OutOfMemory (dpy, setup);
-         return(NULL);
-    }
-    dpy->bufmax = dpy->buffer + conn_buf_size;
-#if USE_XCB
-    dpy->xcb->real_bufmax = dpy->bufmax;
-    dpy->bufmax = dpy->buffer;
+#ifdef __sun /* Backwards compatibility for old Solaris libX11 name */
+	if (xlib_buffer_size == NULL)
+	    xlib_buffer_size = getenv("XSUNBUFFERSIZE");
 #endif
 
+	if (xlib_buffer_size == NULL)
+	    conn_buf_size = XLIBDEFAULTBUFSIZE;
+	else
+	    conn_buf_size = 1024 * strtol(xlib_buffer_size, NULL, 10);
+	if (conn_buf_size < XLIBMINBUFSIZE)
+	    conn_buf_size = XLIBMINBUFSIZE;
+
+	if ((dpy->bufptr = dpy->buffer = Xcalloc(1, conn_buf_size)) == NULL) {
+	    OutOfMemory (dpy);
+	    return(NULL);
+	}
+	dpy->xcb->real_bufmax = dpy->buffer + conn_buf_size;
+	dpy->bufmax = dpy->buffer;
+
 	/* Set up the input event queue and input event queue parameters. */
 	dpy->head = dpy->tail = NULL;
 	dpy->qlen = 0;
@@ -298,68 +249,10 @@ XOpenDisplay (
 	if ((dpy->free_funcs = (_XFreeFuncRec *)Xcalloc(1,
 							sizeof(_XFreeFuncRec)))
 	    == NULL) {
-	    OutOfMemory (dpy, setup);
+	    OutOfMemory (dpy);
 	    return(NULL);
 	}
 
-#if !USE_XCB
-/*
- * The xConnClientPrefix describes the initial connection setup information
- * and is followed by the authorization information.  Sites that are interested
- * in security are strongly encouraged to use an authentication and
- * authorization system such as Kerberos.
- */
-	endian = 1;
-	if (*(char *) &endian)
-	    client.byteOrder = '\154'; /* 'l' */
-	else
-	    client.byteOrder = '\102'; /* 'B' */
-	client.majorVersion = X_PROTOCOL;
-	client.minorVersion = X_PROTOCOL_REVISION;
-	client.nbytesAuthProto = conn_auth_namelen;
-	client.nbytesAuthString = conn_auth_datalen;
-	prefixread = _XSendClientPrefix(dpy, &client,
-					conn_auth_name, conn_auth_data,
-					&prefix);
-	if (prefixread < 0)
-	{
-	    _XDisconnectDisplay (dpy->trans_conn);
-	    Xfree ((char *)dpy);
-	    return(NULL);
-	}
-	if (conn_auth_name) Xfree(conn_auth_name);
-	if (conn_auth_data) Xfree(conn_auth_data);
-/*
- * Now see if connection was accepted...
- */
-	/* these internal functions expect the display to be locked */
-	LockDisplay(dpy);
-
-	if (prefixread == 0)
-	    _XRead (dpy, (char *)&prefix,(long)SIZEOF(xConnSetupPrefix));
-
-	/* an Authenticate reply we weren't expecting? */
-	if (prefix.success != xTrue && prefix.success != xFalse) {
-	    fprintf (stderr,
-      "Xlib: unexpected connection setup reply from server, type %d.\r\n",
-		     prefix.success);
-	    _XDisconnectDisplay (dpy->trans_conn);
-	    Xfree ((char *)dpy);
-	    return(NULL);
-	}
-
-	if (prefix.majorVersion != X_PROTOCOL) {
-	    /* XXX - printing messages marks a bad programming interface */
-	    fprintf (stderr,
-     "Xlib: client uses different protocol version (%d) than server (%d)!\r\n",
-		     X_PROTOCOL, prefix.majorVersion);
-	    _XDisconnectDisplay (dpy->trans_conn);
-	    Xfree ((char *)dpy);
-	    return(NULL);
-	}
-#endif /* !USE_XCB */
-
-#if USE_XCB
 	{
 		const struct xcb_setup_t *xcbsetup = xcb_get_setup(dpy->xcb->connection);
 		memcpy(&prefix, xcbsetup, sizeof(prefix));
@@ -368,38 +261,6 @@ XOpenDisplay (
 		setup += SIZEOF(xConnSetupPrefix);
 		u.setup = (xConnSetup *) setup;
 	}
-#else /* !USE_XCB */
-	setuplength = prefix.length << 2;
-	if ( (u.setup = (xConnSetup *)
-	      (setup =  Xmalloc ((unsigned) setuplength))) == NULL) {
-		_XDisconnectDisplay (dpy->trans_conn);
-		Xfree ((char *)dpy);
-		return(NULL);
-	}
-	_XRead (dpy, (char *)u.setup, setuplength);
-
-/*
- * If the connection was not accepted by the server due to problems,
- * give error message to the user....
- */
-	if (prefix.success != xTrue) {
-		/* XXX - printing messages marks a bad programming interface */
-		fprintf (stderr,
-		      "Xlib: connection to \"%s\" refused by server\r\nXlib: ",
-			 fullname);
-
-		if (prefix.lengthReason > setuplength) {
-		    fprintf (stderr, "Xlib: Broken initial reply: length of reason > length of packet\r\n");
-		}else{
-		    (void) fwrite (u.failure, (Size_t)sizeof(char),
-			       (Size_t)prefix.lengthReason, stderr);
-		    (void) fwrite ("\r\n", sizeof(char), 2, stderr);
-		}
-
-		OutOfMemory(dpy, setup);
-		return (NULL);
-	}
-#endif /* USE_XCB */
 
 /*
  * Check if the reply was long enough to get any information out of it.
@@ -407,7 +268,7 @@ XOpenDisplay (
 	usedbytes = sz_xConnSetup;
 	if (setuplength < usedbytes ) {
 	    fprintf (stderr, "Xlib: Broken initial reply: Too short (%ld)\n", setuplength);
-	    OutOfMemory(dpy, setup);
+	    OutOfMemory(dpy);
 	    return (NULL);
 	}
 
@@ -435,8 +296,8 @@ XOpenDisplay (
 	if (!mask)
 	{
 	    fprintf (stderr, "Xlib: connection to \"%s\" invalid setup\n",
-		     fullname);
-	    OutOfMemory(dpy, setup);
+		     dpy->display_name);
+	    OutOfMemory(dpy);
 	    return (NULL);
 	}
 
@@ -451,13 +312,13 @@ XOpenDisplay (
  */
 	/* Check for a sane vendor string length */
 	if (u.setup->nbytesVendor > 256) {
-	    OutOfMemory(dpy, setup);
+	    OutOfMemory(dpy);
 	    return (NULL);
 	}
 
 	dpy->vendor = (char *) Xmalloc((unsigned) (u.setup->nbytesVendor + 1));
 	if (dpy->vendor == NULL) {
-	    OutOfMemory(dpy, setup);
+	    OutOfMemory(dpy);
 	    return (NULL);
 	}
 	vendorlen = u.setup->nbytesVendor;
@@ -468,7 +329,7 @@ XOpenDisplay (
 	usedbytes += (vendorlen + 3) & ~3;
 	if (setuplength < usedbytes) {
 	    fprintf (stderr, "Xlib: Broken initial reply: Too short (%ld)\n", setuplength);
-	    OutOfMemory(dpy, setup);
+	    OutOfMemory(dpy);
 	    return (NULL);
 	}
 
@@ -485,7 +346,7 @@ XOpenDisplay (
 	    (ScreenFormat *)Xmalloc(
 		(unsigned) (dpy->nformats *sizeof(ScreenFormat)));
 	if (dpy->pixmap_format == NULL) {
-	        OutOfMemory (dpy, setup);
+	        OutOfMemory (dpy);
 		return(NULL);
 	}
 /*
@@ -495,7 +356,7 @@ XOpenDisplay (
 
 	if (setuplength < usedbytes) {
 	    fprintf (stderr, "Xlib: Broken initial reply: Too short (%ld)\n", setuplength);
-	    OutOfMemory (dpy, setup);
+	    OutOfMemory (dpy);
 	    return(NULL);
 	}
 
@@ -514,7 +375,7 @@ XOpenDisplay (
 	dpy->screens =
 	    (Screen *)Xmalloc((unsigned) dpy->nscreens*sizeof(Screen));
 	if (dpy->screens == NULL) {
-	        OutOfMemory (dpy, setup);
+	        OutOfMemory (dpy);
 		return(NULL);
 	}
 
@@ -528,7 +389,7 @@ XOpenDisplay (
 	    usedbytes += sz_xWindowRoot;
 	    if (setuplength < usedbytes) {
 		fprintf (stderr, "Xlib: Broken initial reply: Too short (%ld)\n", setuplength);
-		OutOfMemory (dpy, setup);
+		OutOfMemory (dpy);
 		return(NULL);
 	    }
 
@@ -557,7 +418,7 @@ XOpenDisplay (
 	    sp->depths = (Depth *)Xmalloc(
 			(unsigned)sp->ndepths*sizeof(Depth));
 	    if (sp->depths == NULL) {
-		OutOfMemory (dpy, setup);
+		OutOfMemory (dpy);
 		return(NULL);
 	    }
 	    /*
@@ -569,7 +430,7 @@ XOpenDisplay (
 		usedbytes += sz_xDepth;
 		if (setuplength < usedbytes) {
 		    fprintf (stderr, "Xlib: Broken initial reply: Too short (%ld)\n", setuplength);
-		    OutOfMemory (dpy, setup);
+		    OutOfMemory (dpy);
 		    return(NULL);
 		}
 
@@ -580,7 +441,7 @@ XOpenDisplay (
 		    dp->visuals =
 		      (Visual *)Xmalloc((unsigned)dp->nvisuals*sizeof(Visual));
 		    if (dp->visuals == NULL) {
-			OutOfMemory (dpy, setup);
+			OutOfMemory (dpy);
 			return(NULL);
 		    }
 		    for (k = 0; k < dp->nvisuals; k++) {
@@ -589,7 +450,7 @@ XOpenDisplay (
 			usedbytes += sz_xVisualType;
 			if (setuplength < usedbytes) {
 			    fprintf (stderr, "Xlib: Broken initial reply: Too short (%ld)\n", setuplength);
-			    OutOfMemory (dpy, setup);
+			    OutOfMemory (dpy);
 			    return(NULL);
 			}
 
@@ -622,7 +483,7 @@ XOpenDisplay (
 	    fprintf(stderr, "Xlib: Did not parse entire setup message: "
 	                    "parsed: %ld, message: %ld\n",
 		    usedbytes, setuplength);
-	    OutOfMemory(dpy, setup);
+	    OutOfMemory(dpy);
 	    return(NULL);
 	}
 
@@ -630,30 +491,17 @@ XOpenDisplay (
  * Now start talking to the server to setup all other information...
  */
 
-#if !USE_XCB
-	Xfree (setup);	/* all finished with setup information */
-#endif /* !USE_XCB */
-
 /*
  * Make sure default screen is legal.
  */
 	if (iscreen >= dpy->nscreens) {
-	    OutOfMemory(dpy, (char *) NULL);
+	    OutOfMemory(dpy);
 	    return(NULL);
 	}
 
-#if !USE_XCB
-/*
- * finished calling internal routines, now unlock for external routines
- */
-	UnlockDisplay(dpy);
-#endif /* !USE_XCB */
-
-#if USE_XCB
 	dpy->bigreq_size = xcb_get_maximum_request_length(dpy->xcb->connection);
 	if(dpy->bigreq_size <= dpy->max_request_size)
 		dpy->bigreq_size = 0;
-#endif /* USE_XCB */
 
 /*
  * Set up other stuff clients are always going to use.
@@ -666,7 +514,7 @@ XOpenDisplay (
 	    if ((sp->default_gc = XCreateGC (dpy, sp->root,
 					     GCForeground|GCBackground,
 					     &values)) == NULL) {
-		OutOfMemory(dpy, (char *) NULL);
+		OutOfMemory(dpy);
 		return (NULL);
 	    }
 	}
@@ -684,24 +532,6 @@ XOpenDisplay (
 	{
 	    xGetPropertyReply reply;
 	    xGetPropertyReq *req;
-#if !USE_XCB
-	    _XAsyncHandler async;
-	    _XBigReqState async_state;
-	    xQueryExtensionReq *qreq;
-	    xBigReqEnableReq *breq;
-	    xBigReqEnableReply brep;
-
-	    GetReq(QueryExtension, qreq);
-	    async_state.seq = dpy->request;
-	    async_state.opcode = 0;
-	    async.next = dpy->async_handlers;
-	    async.handler = _XBigReqHandler;
-	    async.data = (XPointer)&async_state;
-	    dpy->async_handlers = &async;
-	    qreq->nbytes = bignamelen;
-	    qreq->length += (bignamelen+3)>>2;
-	    Data(dpy, XBigReqExtensionName, bignamelen);
-#endif /* !USE_XCB */
 
 	    GetReq (GetProperty, req);
 	    req->window = RootWindow(dpy, 0);
@@ -722,16 +552,6 @@ XOpenDisplay (
 		else if (reply.propertyType != None)
 		    _XEatData(dpy, reply.nItems * (reply.format >> 3));
 	    }
-#if !USE_XCB
-	    DeqAsyncHandler(dpy, &async);
-	    if (async_state.opcode) {
-		GetReq(BigReqEnable, breq);
-		breq->reqType = async_state.opcode;
-		breq->brReqType = X_BigReqEnable;
-		if (_XReply(dpy, (xReply *)&brep, 0, xFalse))
-		    dpy->bigreq_size = brep.max_request_size;
-	    }
-#endif /* !USE_XCB */
 	}
 	UnlockDisplay(dpy);
 
@@ -750,35 +570,6 @@ XOpenDisplay (
  	return(dpy);
 }
 
-#if !USE_XCB
-static Bool
-_XBigReqHandler(
-    register Display *dpy,
-    register xReply *rep,
-    char *buf,
-    int len,
-    XPointer data)
-{
-    _XBigReqState *state;
-    xQueryExtensionReply replbuf;
-    xQueryExtensionReply *repl;
-
-    state = (_XBigReqState *)data;
-    if (dpy->last_request_read != state->seq)
-	return False;
-    if (rep->generic.type == X_Error)
-	return True;
-    repl = (xQueryExtensionReply *)
-	_XGetAsyncReply(dpy, (char *)&replbuf, rep, buf, len,
-			(SIZEOF(xQueryExtensionReply) - SIZEOF(xReply)) >> 2,
-			True);
-    if (repl->present)
-	state->opcode = repl->major_opcode;
-    return True;
-}
-#endif /* !USE_XCB */
-
-
 /* XFreeDisplayStructure frees all the storage associated with a
  * Display.  It is used by XOpenDisplay if it runs out of memory,
  * and also by XCloseDisplay.   It needs to check whether all pointers
@@ -788,9 +579,19 @@ _XBigReqHandler(
  * before the first possible call on this.
  */
 
-void _XFreeDisplayStructure(dpy)
-	register Display *dpy;
+void _XFreeDisplayStructure(Display *dpy)
 {
+	/* move all cookies in the EQ to the jar, then free them. */
+	if (dpy->qfree) {
+	    _XQEvent *qelt = dpy->qfree;
+	    while (qelt) {
+		if (_XIsEventCookie(dpy, &qelt->event))
+		    _XStoreEventCookie(dpy, &qelt->event);
+		qelt = qelt->next;
+	    }
+        }
+	if (dpy->cookiejar)
+	    _XFreeEventCookies(dpy);
 	while (dpy->ext_procs) {
 	    _XExtension *ext = dpy->ext_procs;
 	    dpy->ext_procs = ext->next;
@@ -859,8 +660,7 @@ void _XFreeDisplayStructure(dpy)
             Xfree ((char *)dpy->pixmap_format);
 	    }
 
-	if (dpy->display_name)
-	   Xfree (dpy->display_name);
+	free(dpy->display_name);
 	if (dpy->vendor)
 	   Xfree (dpy->vendor);
 
@@ -904,9 +704,7 @@ void _XFreeDisplayStructure(dpy)
 	if (dpy->filedes)
 	    Xfree (dpy->filedes);
 
-#if USE_XCB
 	_XFreeX11XCBStructure(dpy);
-#endif /* USE_XCB */
 
 	Xfree ((char *)dpy);
 }
@@ -914,18 +712,9 @@ void _XFreeDisplayStructure(dpy)
 /* OutOfMemory is called if malloc fails.  XOpenDisplay returns NULL
    after this returns. */
 
-static void OutOfMemory (dpy, setup)
-    Display *dpy;
-    char *setup;
+static void OutOfMemory(Display *dpy)
 {
-#if USE_XCB
     if(dpy->xcb->connection)
 	xcb_disconnect(dpy->xcb->connection);
-#else /* !USE_XCB */
-    _XDisconnectDisplay (dpy->trans_conn);
-#endif /* USE_XCB */
     _XFreeDisplayStructure (dpy);
-#if !USE_XCB
-    if (setup) Xfree (setup);
-#endif /* !USE_XCB */
 }
